// Auth Database to verify logins

unit Auth.Database;

interface

uses
  System.SysUtils, System.Classes, IniFiles, Vcl.Forms, MemDS,
  Data.DB, DBAccess, Uni, UniProvider, PostgreSQLUniProvider, MySQLUniProvider;

type
  TAuthDatabase = class(TDataModule)
    uq: TUniQuery;
    uqMisc: TUniQuery;
    ucKG: TUniConnection;
    MySQLUniProvider1: TMySQLUniProvider;
    procedure DataModuleCreate(Sender: TObject);
    procedure DataModuleDestroy(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  AuthDatabase: TAuthDatabase;

implementation

uses
  System.JSON,
  Common.Config,
  Common.Logging,
  uLibrary;

{%CLASSGROUP 'Vcl.Controls.TControl'}

{$R *.dfm}

procedure TAuthDatabase.DataModuleCreate(Sender: TObject);
var
  iniFile: TIniFile;
  iniStr: string;
begin
  Logger.Log( 5, 'TAuthDatabase.DataModuleCreate' );
  iniFile := TIniFile.Create( ExtractFilePath(Application.ExeName) + 'kgOrdersServer.ini' );
  try
    Logger.Log( 5, '--iniFile entries:' );
    iniStr := iniFile.ReadString('Database', 'Server', '');
    if iniStr.IsEmpty then
      Logger.Log( 5, '----Database->Server: Entry not found' )
    else
    begin
      Logger.Log( 5, '----Database->Server: iniStr' );
      ucKG.Server := iniStr;
    end;

    iniStr := iniFile.ReadString('Database', 'Database', '');
    if iniStr.IsEmpty then
      Logger.Log( 5, '----Database->Database: Entry not found' )
    else
    begin
      Logger.Log( 5, '----Database->Database: iniStr' );
      ucKG.Database := iniStr;
    end;

    iniStr := iniFile.ReadString('Database', 'Username', '');
    if iniStr.IsEmpty then
      Logger.Log( 5, '----Database->Username: Entry not found' )
    else
    begin
      Logger.Log( 5, '----Database->Username: ' + iniStr );
      ucKG.Username := iniStr;
    end;

    iniStr := iniFile.ReadString('Database', 'Password', '');
    if iniStr.IsEmpty then
      Logger.Log( 5, '----Database->Password: Entry not found' )
    else
    begin
      Logger.Log( 5, '----Database->Password: xxxxxxxx' );
      ucKG.Password := iniStr;
    end;

    try
      ucKG.Connect;
    except
      on E: Exception do
      begin
        Logger.Log(3, '--TAuthDatabase.DataModuleCreate -Error connecting to database: ' + E.Message);
      end;
    end;

    Logger.Log(1, '');
  finally
    iniFile.Free;
  end;
end;

procedure TAuthDatabase.DataModuleDestroy(Sender: TObject);
begin
  ucKG.Connected := false;
end;


end.
